@@ -25,7 +25,8 @@ from pymodelextractor.tests.learners_tests.test_mm_lstar_learner import TestMMLS
 from tests.learners_tests.test_general_lstar_learner import TestGeneralLStarLearner
 from tests.learners_tests.test_base_observation_table import TestBaseObservationTable
 from tests.learners_tests.test_partial_table_translator import TestPartialDFATranslator
-from tests.learners_tests.test_ensemble_learner import TestEnsembleBooleanLearner
+from tests.learners_tests.test_ensemble_boolean_learner import TestEnsembleBooleanLearner
+from tests.learners_tests.test_ensemble_probabilistic_learner import TestEnsembleProbabilisticLearner
 
 
 def run():
@@ -52,7 +53,8 @@ def run():
                               TestPDFATeachersLStarCol,
                               TestBaseObservationTable,
                               TestPartialDFATranslator,
-                              TestEnsembleBooleanLearner]
+                              TestEnsembleBooleanLearner,
+                              TestEnsembleProbabilisticLearner]
      loader = TestLoader()
      suites_list = []
      for test_class in test_classes_to_run:
