@@ -1,6 +1,5 @@
 import signal
 from contextlib import contextmanager
-from threading import Timer
 import platform
 
 def is_unix_system():
@@ -23,9 +22,5 @@ def timeout(time):
         # if the timeout is not reached.
         signal.signal(signal.SIGALRM, signal.SIG_IGN)
 
-#def timeout(time):
-#    t = Timer(time, raise_timeout)
-#    t.start()
-
 def raise_timeout(signum, frame):
-    raise TimeoutError
\ No newline at end of file
+    raise TimeoutError
